package com.yidian.shenghuoquan.border.ui.widget

import android.content.Context
import android.util.AttributeSet
import android.view.LayoutInflater
import androidx.constraintlayout.widget.ConstraintLayout
import androidx.databinding.DataBindingUtil
import androidx.recyclerview.widget.LinearLayoutManager
import com.yidian.shenghuoquan.border.R
import com.yidian.shenghuoquan.border.adapter.OrderDetailCommodityListAdapter
import com.yidian.shenghuoquan.border.databinding.BorderViewOrderCommodityInfoBinding
import com.yidian.shenghuoquan.border.dto.OrderDetailDto
import com.yidian.shenghuoquan.border.manager.OrderStatus
import com.yidian.shenghuoquan.border.viewmodel.OrderCommodityInfoViewModel

/**
 * author: yinjiacheng
 * date: 2021/8/21 22:19
 * description: 订单商品信息
 */
class OrderCommodityInfoView @JvmOverloads constructor(context: Context, attrs: AttributeSet? = null, defStyle: Int = 0) :
  ConstraintLayout(context, attrs, defStyle) {

  private val binding =
    DataBindingUtil.inflate<BorderViewOrderCommodityInfoBinding>(
      LayoutInflater.from(getContext()),
      R.layout.border_view_order_commodity_info,
      this,
      true
    )
  private val adapter by lazy { OrderDetailCommodityListAdapter(null) }

  init {
    initRecycleView()
  }

  private fun initRecycleView() {
    binding.rvCommodityList.layoutManager = LinearLayoutManager(context, LinearLayoutManager.VERTICAL, false)
    binding.rvCommodityList.adapter = adapter
    binding.rvCommodityList.addItemDecoration(OrderDetailCommodityListAdapter.OrderDetailCommodityListItemDecoration())
  }

  /**
   * 设置商品信息
   * @param status 订单状态 确认订单时固定传ORDER_STATUS_WAIT_PAY
   * @param info 商品信息
   */
  fun setCommodityInfo(status: OrderStatus, info: OrderDetailDto) {
    binding.vm = OrderCommodityInfoViewModel()
    binding.status = status
    binding.data = info
    adapter.updateData(info.orderItemList)
  }
}
